@@ -1,7 +1,6 @@
 import os
 from .SimpleSVGItems import Line, Path, CubicBezier
 import logging
-import hashlib
 import datetime
 import svgwrite
 from copy import deepcopy
@@ -14,6 +13,7 @@ logger = logging.getLogger("life_line_chart")
 _strings = get_strings('AncestorChart')
 _, _strings = recursive_merge_dict_members(BaseSVGChart.SETTINGS_DESCRIPTION, _strings, remove_unknown_keys=False)
 
+
 class AncestorChart(BaseSVGChart):
     """
     Ancestor Chart
@@ -75,27 +75,19 @@ class AncestorChart(BaseSVGChart):
                 return
 
             if color is None:
-                i = int(hashlib.sha1(" ".join(gr_individual.name).encode(
-                    'utf8')).hexdigest(), 16) % (10 ** 8)
-                c = (i*23 % 255, i*41 % 255, (i*79 % 245) + 10)
-                f = 255/max(c)
-                c = [int(x*f) for x in c]
-                f = min(1, 500/sum(c))
-                c = [int(x*f) for x in c]
-                gr_individual.color = c
+                gr_individual.color = self._instances.color_generator(individual)
             else:
                 gr_individual.color = color
         else:
             gr_individual = individual.graphical_representations[0]
 
-        child_of_families = individual.get_child_of_family()[:1]
+        child_of_families = individual.child_of_families[:1]
         for child_of_family in child_of_families:
             family = self._create_family_graphical_representation(
                 child_of_family)
             family.add_visible_children(individual)
             gr_individual.visible_parent_family = family
             if generations > 0 or generations < 0:
-                # parents = individual.get_father_and_mother()
                 father, mother = child_of_family.get_husband_and_wife()
                 if father:
                     self.select_individuals(
@@ -121,20 +113,13 @@ class AncestorChart(BaseSVGChart):
                 continue
 
             if not child.has_graphical_representation():
-                gr_individual = self._create_individual_graphical_representation(
+                gr_child = self._create_individual_graphical_representation(
                     child)
 
-                if gr_individual is None:
+                if gr_child is None:
                     return
 
-                i = int(hashlib.sha1(" ".join(gr_individual.name).encode(
-                    'utf8')).hexdigest(), 16) % (10 ** 8)
-                c = (i*23 % 255, i*41 % 255, (i*79 % 245) + 10)
-                f = 255/max(c)
-                c = [int(x*f) for x in c]
-                f = min(1, 500/sum(c))
-                c = [int(x*f) for x in c]
-                gr_individual.color = c
+                gr_child.color = self._instances.color_generator(child)
 
                 family.graphical_representations[0].add_visible_children(child)
                 child.graphical_representations[0].visible_parent_family = family.graphical_representations[0]
@@ -155,32 +140,32 @@ class AncestorChart(BaseSVGChart):
         logger.info(f"discovering {individual.plain_name}")
         x_position = x_offset
         gr_individual = individual.graphical_representations[0]
-        gr_individual.x_start = x_position
         self.min_x_index = min(self.min_x_index, x_position)
-        child_of_families = individual.get_child_of_family()
+        child_of_families = individual.child_of_families
 
         # recursively add the father branch
         for local_child_of_family in child_of_families:
             father, mother = local_child_of_family.get_husband_and_wife()
             if father and father.has_graphical_representation():
-                fathers_child_of_families = father.get_child_of_family()
+                gr_father = father.graphical_representations[0]
+                fathers_child_of_families = father.child_of_families
                 if fathers_child_of_families:
                     fathers_born_in_family = fathers_child_of_families[0]
                 else:
                     fathers_born_in_family = None
-                if not father.graphical_representations[0].get_x_position() or local_child_of_family.family_id not in father.graphical_representations[0].get_x_position():
-                    father.graphical_representations[0].visual_placement_child = (
+                if not gr_father.get_x_position() or local_child_of_family.family_id not in gr_father.get_x_position():
+                    gr_father.visual_placement_child = (
                         individual, spouse_family)
                     if local_child_of_family.has_graphical_representation():
                         local_child_of_family.graphical_representations[0].visual_placement_child = individual
-                    # father.graphical_representations[0].visual_placement_child = spouse_family
+                    # gr_father.visual_placement_child = spouse_family
                     self.place_selected_individuals(
                         father, spouse_family, local_child_of_family, fathers_born_in_family, x_position, discovery_cache)
-                    width = father.graphical_representations[0].get_width(
+                    width = gr_father.get_width(
                         local_child_of_family)
                     if local_child_of_family.has_graphical_representation():
                         local_child_of_family.graphical_representations[0].husb_width = \
-                            lambda gr=father.graphical_representations[0], cof=local_child_of_family: gr.get_width(cof)
+                            lambda gr=gr_father, cof=local_child_of_family: gr.get_width(cof)
                     x_position += width
 
         # add the main individual and its visible siblings
@@ -191,24 +176,25 @@ class AncestorChart(BaseSVGChart):
         else:
             siblings = [individual]
         for sibling in siblings:
+            gr_sibling = sibling.graphical_representations[0]
             if sibling.individual_id == individual.individual_id:
-                if sibling.graphical_representations[0].get_x_position() is None or spouse_family is not None and spouse_family.family_id not in sibling.graphical_representations[0].get_x_position():
+                if gr_sibling.get_x_position() is None or spouse_family is not None and spouse_family.family_id not in gr_sibling.get_x_position():
                     # add new position of this spouse family
-                    sibling.graphical_representations[0].set_x_position(
+                    gr_sibling.set_x_position(
                         x_position, spouse_family)
 
-                    if child_of_family and child_of_family.family_id not in sibling.graphical_representations[0].get_x_position():
+                    if child_of_family and child_of_family.family_id not in gr_sibling.get_x_position():
                         # not added yet, so this is the primary cof placement
-                        sibling.graphical_representations[0].set_x_position(
+                        gr_sibling.set_x_position(
                             x_position, child_of_family, True)
 
                     x_position += 1
 
-            elif not sibling.graphical_representations[0].get_x_position() or child_of_family.family_id not in sibling.graphical_representations[0].get_x_position():
-                if not sibling.graphical_representations[0].visual_placement_child:
+            elif not gr_sibling.get_x_position() or child_of_family.family_id not in gr_sibling.get_x_position():
+                if not gr_sibling.visual_placement_child:
                     sibling.graphical_representations[
                         0].visual_placement_child = gr_individual.visual_placement_child
-                    sibling.graphical_representations[0].set_x_position(
+                    gr_sibling.set_x_position(
                         x_position,
                         child_of_family)
                     x_position += 1
@@ -221,25 +207,26 @@ class AncestorChart(BaseSVGChart):
         for local_child_of_family in child_of_families:
             father, mother = local_child_of_family.get_husband_and_wife()
             if mother and mother.has_graphical_representation():
-                mothers_child_of_families = mother.get_child_of_family()
+                gr_mother = mother.graphical_representations[0]
+                mothers_child_of_families = mother.child_of_families
                 if mothers_child_of_families:
                     mothers_born_in_family = mothers_child_of_families[0]
                 else:
                     mothers_born_in_family = None
-                if not mother.graphical_representations[0].get_x_position() or local_child_of_family.family_id not in mother.graphical_representations[0].get_x_position():
-                    mother.graphical_representations[0].visual_placement_child = (
+                if not gr_mother.get_x_position() or local_child_of_family.family_id not in gr_mother.get_x_position():
+                    gr_mother.visual_placement_child = (
                         individual, spouse_family)
                     if local_child_of_family.has_graphical_representation():
                         local_child_of_family.graphical_representations[0].visual_placement_child = individual
-                    # mother.graphical_representations[0].visual_placement_child = spouse_family
+                    # gr_mother.visual_placement_child = spouse_family
                     self.place_selected_individuals(
                         mother, spouse_family, local_child_of_family, mothers_born_in_family, x_position, discovery_cache)
-                    x_min, x_max = mother.graphical_representations[0].get_range(
+                    x_min, x_max = gr_mother.get_range(
                         local_child_of_family)
                     width = x_max - x_min + 1
                     if local_child_of_family.has_graphical_representation():
                         local_child_of_family.graphical_representations[0].wife_width = \
-                            lambda gr=mother.graphical_representations[0], cof=local_child_of_family: gr.get_width(cof)
+                            lambda gr=gr_mother, cof=local_child_of_family: gr.get_width(cof)
                     x_position += width
 
         self.max_x_index = max(self.max_x_index, x_position)
@@ -296,7 +283,7 @@ class AncestorChart(BaseSVGChart):
             family_was_flipped = True
 
         for _, individual in sorted(individuals):
-            cofs = individual.get_child_of_family()
+            cofs = individual.child_of_families
             for cof in cofs:
                 if cof.has_graphical_representation():
                     if cof.husb is None or cof.wife is None \
@@ -327,6 +314,7 @@ class AncestorChart(BaseSVGChart):
         for original_direction_factor, individual in sorted(individuals):
             if individual is None:
                 continue
+            gr_individual = individual.graphical_representations[0]
             i = 0
             if family_was_flipped:
                 direction_factor = - original_direction_factor
@@ -337,44 +325,24 @@ class AncestorChart(BaseSVGChart):
             if self.compression_steps <= 0:
                 continue
 
-            if not individual.graphical_representations[0].visible_parent_family or not individual.graphical_representations[0].visible_parent_family.family_id in individual.graphical_representations[0].get_x_position():
-                # try:
-                #     while i < 50000:
-                #         self._move_single_individual(
-                #             individual, individual.graphical_representations[0].visible_parent_family, direction_factor*1)
-                #         self._check_compressed_x_position(True)
-                #         i += 1
-                # except LifeLineChartCollisionDetected:
-                #     # print("   collision of " + " and ".join([" ".join(a.name) for a in e.args]))
-                #     self._move_single_individual(
-                #         individual, individual.graphical_representations[0].visible_parent_family, -direction_factor*1)
-                # except LifeLineChartCannotMoveIndividual:
-                #     pass
+            if not gr_individual.visible_parent_family or not gr_individual.visible_parent_family.family_id in gr_individual.get_x_position():
                 continue
-            # try:
-            #     while i < 50000:
-            #         _move_single_individual(individual, individual.graphical_representations[0].visible_parent_family, direction_factor*1)
-            #         _check_compressed_x_position(True)
-            #         i += 1
-            # except:
-            #     _move_single_individual(individual, individual.graphical_representations[0].visible_parent_family, -direction_factor*1)
 
             try:
                 while i < 50000:
                     self._move_individual_and_ancestors(
-                        individual, individual.graphical_representations[0].visible_parent_family, direction_factor*1)
+                        individual, gr_individual.visible_parent_family, direction_factor*1)
                     self._check_compressed_x_position(True)
                     i += 1
             except LifeLineChartCollisionDetected as e:
-                # print("   collision of " + " and ".join([" ".join(a.name) for a in e.args]))
                 self._move_individual_and_ancestors(
-                    individual, individual.graphical_representations[0].visible_parent_family, -direction_factor*1)
+                    individual, gr_individual.visible_parent_family, -direction_factor*1)
             except LifeLineChartCannotMoveIndividual as e:
                 pass
             except KeyError as e:
                 pass
             if i != 0:
-                logger.info('moved ' + ' '.join(individual.name) +
+                logger.info('moved ' + ' '.join(individual.get_name()) +
                             ' by ' + str(i * direction_factor * 1))
 
     def modify_layout(self, root_individual_id):
@@ -391,9 +359,6 @@ class AncestorChart(BaseSVGChart):
             old_width = width
             candidantes = set()
             for key in sorted(loli.keys()):
-                # continue
-                # if index == 1:
-                #     continue
                 def collect_candidates(children):
                     for child in children:
                         if len(child.graphical_representations) > 0:
@@ -402,7 +367,7 @@ class AncestorChart(BaseSVGChart):
 
                 individual = loli[key]
                 collect_candidates(individual.children)
-                for cof in individual.individual.get_child_of_family():
+                for cof in individual.individual.child_of_families:
                     collect_candidates(cof.get_children())
 
             # candidantes = set()
@@ -461,11 +426,6 @@ class AncestorChart(BaseSVGChart):
         else:
             _, _, _, self.position_to_person_map = self._check_compressed_x_position(
                 False)
-        # for collision in collisions:
-        #     if collision[1] is None:
-        #         print("collision of " + " ".join(collision[0].name))
-        #     else:
-        #         print("collision of " + " ".join(collision[0].name) + " with " + " ".join(collision[1].name))
 
     def update_chart(self, filter_lambda=None, color_lambda=None, images_lambda=None, rebuild_all=False, update_view=False):
         rebuild_all = rebuild_all or self._positioning != self._backup_positioning or \
