@@ -257,7 +257,7 @@ class BaseChart():
                 # len(x_pos) <= 1 or
                 if list(sorted(x_pos.values()))[0][1] != x_pos[family_id][1]:
                     return
-                # for cof in individual.get_child_of_family():
+                # for cof in individual.child_of_families:
                 cof = individual.graphical_representations[0].visible_parent_family
                 if cof and cof.visual_placement_child and cof.visual_placement_child.individual_id == individual.individual_id:
                     if cof.husb:
@@ -431,8 +431,8 @@ class BaseChart():
                     failed.append(x_index)
                     # value = index_map[x_index]
                     logger.error(
-                        "failed: " + str((x_index, value[2].family_id, gr_individual.name, v[x_index])))
-                    # raise RuntimeError((x_index, key, gr_individual.name))
+                        "failed: " + str((x_index, value[2].family_id, gr_individual.individual.plain_name, v[x_index])))
+                    # raise RuntimeError((x_index, key, gr_individual.individual.plain_name))
         full_index_list = list(sorted(v.keys()))
         for i in range(max(full_index_list)):
             if i not in full_index_list:
