@@ -1,7 +1,6 @@
 import os
 from .SimpleSVGItems import Line, Path, CubicBezier
 import logging
-import hashlib
 import datetime
 import svgwrite
 from copy import deepcopy
@@ -12,6 +11,8 @@ from .BaseChart import BaseChart
 logger = logging.getLogger("life_line_chart")
 
 cardano_instance = None
+
+
 class Cardano:
     J = None
     Jc = None
@@ -93,8 +94,8 @@ class BaseSVGChart(BaseChart):
                     failed.append(x_index)
                     # value = index_map[x_index]
                     logger.error(
-                        "failed: " + str((x_index, value[2].family_id, gr_individual.name, v[x_index])))
-                    # raise RuntimeError((x_index, key, gr_individual.name))
+                        "failed: " + str((x_index, value[2].family_id, gr_individual.individual.plain_name, v[x_index])))
+                    # raise RuntimeError((x_index, key, gr_individual.individual.plain_name))
         full_index_list = list(sorted(v.keys()))
         for i in range(max(full_index_list)):
             if i not in full_index_list:
@@ -212,7 +213,7 @@ class BaseSVGChart(BaseChart):
             death_event = gr_individual.get_death_event()
 
             # individual_id = gr_individual.individual_id
-            individual_name = gr_individual.name
+            individual_name = gr_individual.get_name()
             # positions[individual_id]
 
             # individual = self._instances[('i',individual_id)]
@@ -265,7 +266,7 @@ class BaseSVGChart(BaseChart):
                                 child_x_indices.append(visible_child.graphical_representations[0].get_x_position()[
                                                        graphical_representation_marriage_family.family_id][1])
                             except:
-                                logger.error('something went wrong with ' + "".join(visible_child.name) +
+                                logger.error('something went wrong with ' + "".join(visible_child.get_name()) +
                                              ". The position family 0 is not equal to the placement...")
                         if len(child_x_indices) > 0:
                             # calculate the middle over the children
@@ -287,7 +288,7 @@ class BaseSVGChart(BaseChart):
                     marriage_ordinals.append(
                         graphical_representation_marriage_family.marriage['ordinal_value'])
                     marriage_labels.append(
-                        str(graphical_representation_marriage_family.label))
+                        str(graphical_representation_marriage_family.marriage_label))
 
             # generate event node information
             knots = []
@@ -583,7 +584,7 @@ class BaseSVGChart(BaseChart):
 
         if filename is None:
             filename = 'ancestors_of_' + \
-                "".join(self._instances[('i', individual_id)].name).replace(
+                "".join(self._instances[('i', individual_id)].get_name()).replace(
                     ' ', '')
             if self._positioning['flip_to_optimize']:
                 filename += '_flipped'
