@@ -23,23 +23,11 @@ class GedcomIndividual(BaseIndividual):
         estimate_birth_date(self, self._instances)
         estimate_death_date(self)
 
-    def _get_name(self):
+    def get_name(self):
         if 'NAME' in self._database_indi[self.individual_id]:
             return self._database_indi[self.individual_id]['NAME']['tag_data'].split('/')
         else:
-            return [""]
-
-    name = property(_get_name)
-
-    def _get_father_and_mother(self):
-        family_id = self._database_indi[self.individual_id]['FAMC']['tag_data']
-        husb = self._database_fam[family_id].get('HUSB')
-        wife = self._database_fam[family_id].get('WIFE')
-        if husb:
-            husb = husb['tag_data']
-        if wife:
-            wife = wife['tag_data']
-        return husb, wife
+            return ["", ""]
 
     def _get_marriage_family_ids(self):
         try:
